@@ -1,4 +1,4 @@
-`survBayes.b.fctn.Lambda.quad.a` <-
+"survBayes.b.fctn.Lambda.quad.a" <-
 function (nth, time, time.int, time.int.mat, hr, int, int.delta, 
     BB.int, BB.time, KK, taylor.int, taylor.time) 
 {
@@ -14,4 +14,3 @@ function (nth, time, time.int, time.int.mat, hr, int, int.delta,
     weighted.Lambda.ind <- (interval.part + rest.part)
     return(sum(hr * weighted.Lambda.ind))
 }
-
