@@ -1,4 +1,4 @@
-`survBayes.control.gamma.frailty` <-
+"survBayes.control.gamma.frailty" <-
 function (mu.cl = 1, prec.tau.cl = 1e-04) 
 {
     if (mu.cl < 0) 
@@ -8,4 +8,3 @@ function (mu.cl = 1, prec.tau.cl = 1e-04)
     list(mu.cl = mu.cl, prec.tau.cl = prec.tau.cl, mu.cl.miss = missing(mu.cl), 
         prec.tau.cl.miss = missing(prec.tau.cl))
 }
-
